@@ -32,23 +32,21 @@ using std::endl;
 using namespace H5;
 
 #include "h5test.h"
-#include "h5cpputil.h"
+#include "h5cpputil.h"  // C++ utilility header file
 
-
 /*-------------------------------------------------------------------------
  * Function:    test_report
  *
- * Purpose:     Prints out the number of errors for the tests indicated
+ * Purpose      Prints out the number of errors for the tests indicated
  *              by 'testname,' if there were any failures occurred.  If
  *              no failure, test_report prints out the tests passed message.
  *
- * Return:      if any failure has occurred:    1
+ * Return       if any failure has occurred: 1
  *
- *              if no failure occurs:   0
+ *              if no failure occurs: 0
  *
- * Programmer:  Binh-Minh Ribler (using C code segment for reporting tests)
+ * Programmer   Binh-Minh Ribler (using C code segment for reporting tests)
  *              Friday, February 6, 2001
- *
  *-------------------------------------------------------------------------
  */
 int test_report( int nerrors, const H5std_string& testname )
@@ -58,10 +56,10 @@ int test_report( int nerrors, const H5std_string& testname )
       nerrors = MAX(1, nerrors);
         if (1 == nerrors)
             cerr << "***** " << nerrors << testname
-                                        << " TEST FAILED! *****" << endl;
+                 << " TEST FAILED! *****" << endl;
         else
             cerr << "***** " << nerrors << testname
-                                        << " TESTS FAILED! *****" << endl;
+                 << " TESTS FAILED! *****" << endl;
       return 1;
    }
    else
@@ -74,11 +72,11 @@ int test_report( int nerrors, const H5std_string& testname )
 /*-------------------------------------------------------------------------
  * Function:    issue_fail_msg
  *
- * Purpose:     Displays that a function has failed with its location.
+ * Purpose      Displays that a function has failed with its location.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (copied and modified macro CHECK from C)
+ * Programmer   Binh-Minh Ribler (copied and modified macro CHECK from C)
  *              Monday, December 20, 2004
  *
  *-------------------------------------------------------------------------
@@ -97,11 +95,11 @@ void issue_fail_msg(const char* where, int line, const char* file_name,
 /*-------------------------------------------------------------------------
  * Function:    issue_fail_msg
  *
- * Purpose:     Displays that a function has failed with its location.
+ * Purpose      Displays that a function has failed with its location.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (copied and modified macro CHECK from C)
+ * Programmer   Binh-Minh Ribler (copied and modified macro CHECK from C)
  *              Monday, December 20, 2004
  *
  *-------------------------------------------------------------------------
@@ -121,20 +119,19 @@ void issue_fail_msg(const char* where, int line, const char* file_name,
 /*-------------------------------------------------------------------------
  * Function:    check_values
  *
- * Purpose:     Checks a read value against the written value.  If they are
+ * Purpose      Checks a read value against the written value.  If they are
  *              different, the function will print out a message and the
  *              different values.  This function is made to reuse the code
  *              segment that is used in various places throughout
  *              the test code.  Where the C version of this code segment
  *              "goto error," this function will return -1.
  *
- * Return:      Success:        0
+ * Return       Success: 0
  *
- *              Failure:        -1
+ *              Failure: -1
  *
- * Programmer:  Binh-Minh Ribler (using C code segment for checking values)
+ * Programmer   Binh-Minh Ribler (using C code segment for checking values)
  *              Friday, February 6, 2001
- *
  *-------------------------------------------------------------------------
  */
 int check_values (hsize_t i, hsize_t j, int apoint, int acheck)
@@ -143,26 +140,51 @@ int check_values (hsize_t i, hsize_t j, int apoint, int acheck)
     {
         cerr << "    Read different values than written.\n" << endl;
         cerr << "    At index " << static_cast<unsigned long>(i) << "," <<
-        static_cast<unsigned long>(j) << endl;
+           static_cast<unsigned long>(j) << endl;
         return -1;
     }
     return 0;
 } // check_values
 
+/*-------------------------------------------------------------------------
+ * Function:    check_values
+ *
+ * Purpose      Checks a char string pointer for NULL.  If it is NULL,
+ *              the function will print out a message
+ *
+ * Return       Success: 0
+ *
+ *              Failure: -1
+ *
+ * Programmer   Binh-Minh Ribler (using C code segment for checking values)
+ *              Friday, September 16, 2016
+ *
+ *-------------------------------------------------------------------------
+ */
+void check_values(const char *value, const char* msg, int line, const char* file_name)
+{
+    if (value == NULL)
+    {
+        cerr << endl;
+        cerr << "*** ERROR: " << msg << ", at line " << line << endl;
+        IncTestNumErrs();
+        throw TestFailedException(file_name, msg);
+    }
+}
+
 /*-------------------------------------------------------------------------
  * Function:    verify_val (const char*, const char*,...)
  *
- * Purpose:     Compares two character strings.  If they are
+ * Purpose      Compares two character strings.  If they are
  *              different, the function will print out a message and the
  *              different values.
  *
- * Return:      Success:        0
+ * Return       Success: 0
  *
- *              Failure:        -1
+ *              Failure: -1
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              May 2, 2010
- *
  *-------------------------------------------------------------------------
  */
 void verify_val(const char* x, const char* value, const char* where, int line, const char* file_name)
@@ -179,7 +201,7 @@ void verify_val(const char* x, const char* value, const char* where, int line, c
         cerr << "*** UNEXPECTED VALUE from " << where << " should be "
              << value << ", but is " << x << " at line " << line
              << " in " << file_name << endl;
-        IncTestNumErrs();
+        //IncTestNumErrs();
         throw TestFailedException(where, "");
     }
 }
@@ -192,7 +214,7 @@ InvalidActionException::InvalidActionException():Exception(){}
 //--------------------------------------------------------------------------
 // Function:    InvalidActionException overloaded constructor
 //
-// Purpose:     Creates an InvalidActionException with the name of the function,
+// Purpose      Creates an InvalidActionException with the name of the function,
 //              which the failure should have occurred but didn't, and a
 //              message explaining why it should fail.
 // Parameters
@@ -214,7 +236,7 @@ TestFailedException::TestFailedException():Exception(){}
 //--------------------------------------------------------------------------
 // Function:    TestFailedException overloaded constructor
 //
-// Purpose:     Creates an TestFailedException with the name of the function,
+// Purpose      Creates an TestFailedException with the name of the function,
 //              which the failure should have occurred but didn't, and a
 //              message explaining why it should fail.
 // Parameters
