@@ -11,18 +11,18 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Robb Matzke <matzke@llnl.gov>
+/* Programmer:  Robb Matzke
  *              Wednesday, September 30, 1998
  *
- * Purpose:	The fill message indicates a bit pattern to use for
- *		uninitialized data points of a dataset.
+ * Purpose:    The fill message indicates a bit pattern to use for
+ *        uninitialized data points of a dataset.
  */
 
 #include "H5Omodule.h"          /* This source code file is part of the H5O module */
 
 
 #include "H5private.h"      /* Generic Functions    */
-#include "H5Dprivate.h"     /* Datasets	            */
+#include "H5Dprivate.h"     /* Datasets                */
 #include "H5Eprivate.h"     /* Error handling       */
 #include "H5FLprivate.h"    /* Free Lists           */
 #include "H5Iprivate.h"     /* IDs                  */
@@ -32,78 +32,78 @@
 #include "H5Sprivate.h"     /* Dataspaces           */
 
 
-static void  *H5O_fill_old_decode(H5F_t *f, hid_t dxpl_id, H5O_t *open_oh,
-    unsigned mesg_flags, unsigned *ioflags, size_t p_size, const uint8_t *p);
+static void  *H5O_fill_old_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags,
+    unsigned *ioflags, size_t p_size, const uint8_t *p);
 static herr_t H5O_fill_old_encode(H5F_t *f, uint8_t *p, const void *_mesg);
 static size_t H5O_fill_old_size(const H5F_t *f, const void *_mesg);
-static void  *H5O_fill_new_decode(H5F_t *f, hid_t dxpl_id, H5O_t *open_oh,
-    unsigned mesg_flags, unsigned *ioflags, size_t p_size, const uint8_t *p);
+static void  *H5O_fill_new_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags,
+    unsigned *ioflags, size_t p_size, const uint8_t *p);
 static herr_t H5O_fill_new_encode(H5F_t *f, uint8_t *p, const void *_mesg);
 static size_t H5O_fill_new_size(const H5F_t *f, const void *_mesg);
 static void  *H5O_fill_copy(const void *_mesg, void *_dest);
-static herr_t H5O_fill_reset(void *_mesg);
-static herr_t H5O_fill_free(void *_mesg);
-static herr_t H5O_fill_pre_copy_file(H5F_t *file_src, const void *mesg_src,
+static herr_t H5O__fill_reset(void *_mesg);
+static herr_t H5O__fill_free(void *_mesg);
+static herr_t H5O__fill_pre_copy_file(H5F_t *file_src, const void *mesg_src,
     hbool_t *deleted, const H5O_copy_t *cpy_info, void *udata);
-static herr_t H5O_fill_debug(H5F_t *f, hid_t dxpl_id, const void *_mesg, FILE *stream,
-			     int indent, int fwidth);
+static herr_t H5O__fill_debug(H5F_t *f, const void *_mesg, FILE *stream,
+    int indent, int fwidth);
 
 /* Set up & include shared message "interface" info */
-#define H5O_SHARED_TYPE			H5O_MSG_FILL
-#define H5O_SHARED_DECODE		H5O_fill_shared_decode
-#define H5O_SHARED_DECODE_REAL		H5O_fill_old_decode
-#define H5O_SHARED_ENCODE		H5O_fill_shared_encode
-#define H5O_SHARED_ENCODE_REAL		H5O_fill_old_encode
-#define H5O_SHARED_SIZE			H5O_fill_shared_size
-#define H5O_SHARED_SIZE_REAL		H5O_fill_old_size
-#define H5O_SHARED_DELETE		H5O_fill_shared_delete
+#define H5O_SHARED_TYPE            H5O_MSG_FILL
+#define H5O_SHARED_DECODE        H5O_fill_shared_decode
+#define H5O_SHARED_DECODE_REAL        H5O_fill_old_decode
+#define H5O_SHARED_ENCODE        H5O_fill_shared_encode
+#define H5O_SHARED_ENCODE_REAL        H5O_fill_old_encode
+#define H5O_SHARED_SIZE            H5O_fill_shared_size
+#define H5O_SHARED_SIZE_REAL        H5O_fill_old_size
+#define H5O_SHARED_DELETE        H5O__fill_shared_delete
 #undef H5O_SHARED_DELETE_REAL
-#define H5O_SHARED_LINK			H5O_fill_shared_link
+#define H5O_SHARED_LINK            H5O__fill_shared_link
 #undef H5O_SHARED_LINK_REAL
-#define H5O_SHARED_COPY_FILE		H5O_fill_shared_copy_file
+#define H5O_SHARED_COPY_FILE        H5O__fill_shared_copy_file
 #undef H5O_SHARED_COPY_FILE_REAL
-#define H5O_SHARED_POST_COPY_FILE	H5O_fill_shared_post_copy_file
+#define H5O_SHARED_POST_COPY_FILE    H5O_fill_shared_post_copy_file
 #undef H5O_SHARED_POST_COPY_FILE_REAL
 #undef  H5O_SHARED_POST_COPY_FILE_UPD
-#define H5O_SHARED_DEBUG		H5O_fill_shared_debug
-#define H5O_SHARED_DEBUG_REAL		H5O_fill_debug
-#include "H5Oshared.h"			/* Shared Object Header Message Callbacks */
+#define H5O_SHARED_DEBUG        H5O_fill_shared_debug
+#define H5O_SHARED_DEBUG_REAL        H5O__fill_debug
+#include "H5Oshared.h"            /* Shared Object Header Message Callbacks */
 
 /* Set up & include shared message "interface" info */
 /* (Kludgy 'undef's in order to re-include the H5Oshared.h header) */
 #undef H5O_SHARED_TYPE
-#define H5O_SHARED_TYPE			H5O_MSG_FILL_NEW
+#define H5O_SHARED_TYPE            H5O_MSG_FILL_NEW
 #undef H5O_SHARED_DECODE
-#define H5O_SHARED_DECODE		H5O_fill_new_shared_decode
+#define H5O_SHARED_DECODE        H5O_fill_new_shared_decode
 #undef H5O_SHARED_DECODE_REAL
-#define H5O_SHARED_DECODE_REAL		H5O_fill_new_decode
+#define H5O_SHARED_DECODE_REAL        H5O_fill_new_decode
 #undef H5O_SHARED_ENCODE
-#define H5O_SHARED_ENCODE		H5O_fill_new_shared_encode
+#define H5O_SHARED_ENCODE        H5O_fill_new_shared_encode
 #undef H5O_SHARED_ENCODE_REAL
-#define H5O_SHARED_ENCODE_REAL		H5O_fill_new_encode
+#define H5O_SHARED_ENCODE_REAL        H5O_fill_new_encode
 #undef H5O_SHARED_SIZE
-#define H5O_SHARED_SIZE			H5O_fill_new_shared_size
+#define H5O_SHARED_SIZE            H5O_fill_new_shared_size
 #undef H5O_SHARED_SIZE_REAL
-#define H5O_SHARED_SIZE_REAL		H5O_fill_new_size
+#define H5O_SHARED_SIZE_REAL        H5O_fill_new_size
 #undef H5O_SHARED_DELETE
-#define H5O_SHARED_DELETE		H5O_fill_new_shared_delete
+#define H5O_SHARED_DELETE        H5O__fill_new_shared_delete
 #undef H5O_SHARED_DELETE_REAL
 #undef H5O_SHARED_LINK
-#define H5O_SHARED_LINK			H5O_fill_new_shared_link
+#define H5O_SHARED_LINK            H5O__fill_new_shared_link
 #undef H5O_SHARED_LINK_REAL
 #undef H5O_SHARED_COPY_FILE
-#define H5O_SHARED_COPY_FILE		H5O_fill_new_shared_copy_file
+#define H5O_SHARED_COPY_FILE        H5O__fill_new_shared_copy_file
 #undef H5O_SHARED_COPY_FILE_REAL
 #undef H5O_SHARED_POST_COPY_FILE
-#define H5O_SHARED_POST_COPY_FILE	H5O_fill_new_shared_post_copy_file
+#define H5O_SHARED_POST_COPY_FILE    H5O_fill_new_shared_post_copy_file
 #undef H5O_SHARED_POST_COPY_FILE_REAL
 #undef  H5O_SHARED_POST_COPY_FILE_UPD
 #undef H5O_SHARED_DEBUG
-#define H5O_SHARED_DEBUG		H5O_fill_new_shared_debug
+#define H5O_SHARED_DEBUG        H5O_fill_new_shared_debug
 #undef H5O_SHARED_DEBUG_REAL
-#define H5O_SHARED_DEBUG_REAL		H5O_fill_debug
+#define H5O_SHARED_DEBUG_REAL        H5O__fill_debug
 #undef H5Oshared_H
-#include "H5Oshared.h"			/* Shared Object Header Message Callbacks */
+#include "H5Oshared.h"            /* Shared Object Header Message Callbacks */
 
 /* This message derives from H5O message class, for old fill value before version 1.5 */
 const H5O_msg_class_t H5O_MSG_FILL[1] = {{
@@ -115,14 +115,14 @@ const H5O_msg_class_t H5O_MSG_FILL[1] = {{
     H5O_fill_shared_encode,     /*encode message                            */
     H5O_fill_copy,              /*copy the native value                     */
     H5O_fill_shared_size,       /*raw message size                          */
-    H5O_fill_reset,             /*free internal memory                      */
-    H5O_fill_free,              /* free method                              */
-    H5O_fill_shared_delete,     /* file delete method                       */
-    H5O_fill_shared_link,       /* link method                              */
+    H5O__fill_reset,            /*free internal memory                      */
+    H5O__fill_free,             /* free method                              */
+    H5O__fill_shared_delete,    /* file delete method                       */
+    H5O__fill_shared_link,      /* link method                              */
     NULL,                       /* set share method                         */
     NULL,                       /*can share method                          */
-    H5O_fill_pre_copy_file,     /* pre copy native value to file            */
-    H5O_fill_shared_copy_file,  /* copy native value to file                */
+    H5O__fill_pre_copy_file,    /* pre copy native value to file            */
+    H5O__fill_shared_copy_file, /* copy native value to file                */
     H5O_fill_shared_post_copy_file, /* post copy native value to file       */
     NULL,                       /* get creation index                       */
     NULL,                       /* set creation index                       */
@@ -139,24 +139,24 @@ const H5O_msg_class_t H5O_MSG_FILL_NEW[1] = {{
     H5O_fill_new_shared_encode,         /*encode message                    */
     H5O_fill_copy,                      /*copy the native value             */
     H5O_fill_new_shared_size,           /*raw message size                  */
-    H5O_fill_reset,                     /*free internal memory              */
-    H5O_fill_free,                      /* free method                      */
-    H5O_fill_new_shared_delete,         /* file delete method               */
-    H5O_fill_new_shared_link,           /* link method                      */
+    H5O__fill_reset,                    /*free internal memory              */
+    H5O__fill_free,                     /* free method                      */
+    H5O__fill_new_shared_delete,        /* file delete method               */
+    H5O__fill_new_shared_link,          /* link method                      */
     NULL,                               /* set share method                 */
     NULL,                               /*can share method                  */
-    H5O_fill_pre_copy_file,             /* pre copy native value to file    */
-    H5O_fill_new_shared_copy_file,      /* copy native value to file        */
+    H5O__fill_pre_copy_file,            /* pre copy native value to file    */
+    H5O__fill_new_shared_copy_file,      /* copy native value to file        */
     H5O_fill_new_shared_post_copy_file, /* post copy native value to file   */
     NULL,                               /* get creation index               */
     NULL,                               /* set creation index               */
-    H5O_fill_new_shared_debug           /*debug the message	                */
+    H5O_fill_new_shared_debug           /*debug the message                    */
 }};
 
 /* Format version bounds for fill value */
 const unsigned H5O_fill_ver_bounds[] = {
     H5O_FILL_VERSION_1,     /* H5F_LIBVER_EARLIEST */
-    H5O_FILL_VERSION_2,     /* H5F_LIBVER_V18 */
+    H5O_FILL_VERSION_3,     /* H5F_LIBVER_V18 */
     H5O_FILL_VERSION_LATEST /* H5F_LIBVER_LATEST */
 };
 
@@ -175,15 +175,15 @@ H5FL_DEFINE(H5O_fill_t);
 /* Declare extern the free list to manage blocks of type conversion data */
 H5FL_BLK_EXTERN(type_conv);
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_new_decode
+ * Function:    H5O_fill_new_decode
  *
- * Purpose:	Decode a new fill value message.  The new fill value
+ * Purpose:    Decode a new fill value message.  The new fill value
  *          message is fill value plus space allocation time and
  *          fill value writing time and whether fill value is defined.
  *
- * Return:	Success:    Ptr to new message in native struct.
+ * Return:    Success:    Ptr to new message in native struct.
  *          Failure:    NULL
  *
  * Programmer:  Raymond Lu
@@ -192,11 +192,11 @@ H5FL_BLK_EXTERN(type_conv);
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_fill_new_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5_ATTR_UNUSED *open_oh,
+H5O_fill_new_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
     unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
-    size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+    size_t p_size, const uint8_t *p)
 {
-    H5O_fill_t	*fill = NULL;
+    H5O_fill_t    *fill = NULL;
     void *ret_value = NULL;     /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
@@ -228,9 +228,11 @@ H5O_fill_new_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t
             INT32DECODE(p, fill->size);
             if(fill->size > 0) {
                 H5_CHECK_OVERFLOW(fill->size, ssize_t, size_t);
+                if((size_t)fill->size > p_size)
+                    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "destination buffer too small")
                 if(NULL == (fill->buf = H5MM_malloc((size_t)fill->size)))
                     HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
-                HDmemcpy(fill->buf, p, (size_t)fill->size);
+                H5MM_memcpy(fill->buf, p, (size_t)fill->size);
             } /* end if */
         } /* end if */
         else
@@ -268,7 +270,7 @@ H5O_fill_new_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t
             H5_CHECK_OVERFLOW(fill->size, ssize_t, size_t);
             if(NULL == (fill->buf = H5MM_malloc((size_t)fill->size)))
                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
-            HDmemcpy(fill->buf, p, (size_t)fill->size);
+            H5MM_memcpy(fill->buf, p, (size_t)fill->size);
 
             /* Set the "defined" flag */
             fill->fill_defined = TRUE;
@@ -292,7 +294,7 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_new_decode() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    H5O_fill_old_decode
  *
@@ -307,11 +309,13 @@ done:
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_fill_old_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5_ATTR_UNUSED *open_oh,
+H5O_fill_old_decode(H5F_t *f, H5O_t *open_oh,
     unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
-    size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+    size_t p_size, const uint8_t *p)
 {
-    H5O_fill_t *fill = NULL;	/* Decoded fill value message */
+    H5O_fill_t *fill = NULL;    /* Decoded fill value message */
+    htri_t exists = FALSE;
+    H5T_t *dt = NULL;
     void *ret_value = NULL;     /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
@@ -332,9 +336,24 @@ H5O_fill_old_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t
 
     /* Only decode the fill value itself if there is one */
     if(fill->size > 0) {
+        H5_CHECK_OVERFLOW(fill->size, ssize_t, size_t);
+        if((size_t)fill->size > p_size)
+            HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "destination buffer too small")
+
+        /* Get the datatype message  */
+        if((exists = H5O_msg_exists_oh(open_oh, H5O_DTYPE_ID)) < 0)
+            HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, NULL, "unable to read object header")
+        if(exists) {
+            if((dt = H5O_msg_read_oh(f, open_oh, H5O_DTYPE_ID, NULL)) < 0)
+                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, NULL, "can't read DTYPE message")
+            /* Verify size */
+            if(fill->size != H5T_GET_SIZE(dt))
+                HGOTO_ERROR(H5E_SYM, H5E_CANTGET, NULL, "inconsistent fill value size")
+        }
+
         if(NULL == (fill->buf = H5MM_malloc((size_t)fill->size)))
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
-        HDmemcpy(fill->buf, p, (size_t)fill->size);
+        H5MM_memcpy(fill->buf, p, (size_t)fill->size);
         fill->fill_defined = TRUE;
     } /* end if */
     else
@@ -344,24 +363,27 @@ H5O_fill_old_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t
     ret_value = (void*)fill;
 
 done:
+    if(dt)
+        H5O_msg_free(H5O_DTYPE_ID, dt);
+
     if(!ret_value && fill) {
         if(fill->buf)
             H5MM_xfree(fill->buf);
-	    fill = H5FL_FREE(H5O_fill_t, fill);
+        fill = H5FL_FREE(H5O_fill_t, fill);
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_old_decode() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_new_encode
+ * Function:    H5O_fill_new_encode
  *
- * Purpose:	Encode a new fill value message.  The new fill value
+ * Purpose:    Encode a new fill value message.  The new fill value
  *          message is fill value plus space allocation time and
  *          fill value writing time and whether fill value is defined.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
  * Programmer:  Raymond Lu
  *              Feb 26, 2002
@@ -371,7 +393,7 @@ done:
 static herr_t
 H5O_fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
 {
-    const H5O_fill_t	*fill = (const H5O_fill_t *)_fill;
+    const H5O_fill_t    *fill = (const H5O_fill_t *)_fill;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -384,10 +406,10 @@ H5O_fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
 
     if(fill->version < H5O_FILL_VERSION_3) {
         /* Space allocation time */
-        *p++ = fill->alloc_time;
+        *p++ = (uint8_t)fill->alloc_time;
 
         /* Fill value writing time */
-        *p++ = fill->fill_time;
+        *p++ = (uint8_t)fill->fill_time;
 
         /* Whether fill value is defined */
         *p++ = (uint8_t)fill->fill_defined;
@@ -398,7 +420,7 @@ H5O_fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
             if(fill->size > 0)
                 if(fill->buf) {
                     H5_CHECK_OVERFLOW(fill->size, ssize_t, size_t);
-                    HDmemcpy(p, fill->buf, (size_t)fill->size);
+                    H5MM_memcpy(p, fill->buf, (size_t)fill->size);
                 } /* end if */
         } /* end if */
     } /* end if */
@@ -437,7 +459,7 @@ H5O_fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
             /* Encode the fill value */
             HDassert(fill->buf);
             H5_CHECK_OVERFLOW(fill->size, ssize_t, size_t);
-            HDmemcpy(p, fill->buf, (size_t)fill->size);
+            H5MM_memcpy(p, fill->buf, (size_t)fill->size);
         } /* end if */
         else {
             /* Flags */
@@ -451,7 +473,7 @@ H5O_fill_new_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O_fill_new_encode() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    H5O_fill_old_encode
  *
@@ -477,22 +499,22 @@ H5O_fill_old_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p, const void *_fill)
 
     UINT32ENCODE(p, fill->size);
     if(fill->buf)
-        HDmemcpy(p, fill->buf, (size_t)fill->size);
+        H5MM_memcpy(p, fill->buf, (size_t)fill->size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O_fill_old_encode() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_copy
+ * Function:    H5O_fill_copy
  *
- * Purpose:	Copies a message from _MESG to _DEST, allocating _DEST if
- *		necessary.  The new fill value message is fill value plus
- *		space allocation time and fill value writing time and
- *		whether fill value is defined.
+ * Purpose:    Copies a message from _MESG to _DEST, allocating _DEST if
+ *        necessary.  The new fill value message is fill value plus
+ *        space allocation time and fill value writing time and
+ *        whether fill value is defined.
  *
- * Return:	Success:	Ptr to _DEST
- *		    Failure:	NULL
+ * Return:    Success:    Ptr to _DEST
+ *            Failure:    NULL
  *
  * Programmer:  Raymond Lu
  *              Feb 26, 2002
@@ -529,14 +551,14 @@ H5O_fill_copy(const void *_src, void *_dst)
         H5_CHECK_OVERFLOW(src->size, ssize_t, size_t);
         if(NULL == (dst->buf = H5MM_malloc((size_t)src->size)))
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed for fill value")
-        HDmemcpy(dst->buf, src->buf, (size_t)src->size);
+        H5MM_memcpy(dst->buf, src->buf, (size_t)src->size);
 
         /* Check for needing to convert/copy fill value */
         if(src->type) {
             H5T_path_t *tpath;      /* Conversion information */
 
             /* Set up type conversion function */
-            if(NULL == (tpath = H5T_path_find(src->type, dst->type, NULL, NULL, H5AC_noio_dxpl_id, FALSE)))
+            if(NULL == (tpath = H5T_path_find(src->type, dst->type)))
                 HGOTO_ERROR(H5E_OHDR, H5E_UNSUPPORTED, NULL, "unable to convert between src and dst data types")
 
             /* If necessary, convert fill value datatypes (which copies VL components, etc.) */
@@ -564,7 +586,7 @@ H5O_fill_copy(const void *_src, void *_dst)
                 } /* end if */
 
                 /* Convert fill value */
-                if(H5T_convert(tpath, src_id, dst_id, (size_t)1, (size_t)0, (size_t)0, dst->buf, bkg_buf, H5AC_noio_dxpl_id) < 0) {
+                if(H5T_convert(tpath, src_id, dst_id, (size_t)1, (size_t)0, (size_t)0, dst->buf, bkg_buf) < 0) {
                     H5I_dec_ref(src_id);
                     H5I_dec_ref(dst_id);
                     if(bkg_buf)
@@ -591,7 +613,7 @@ done:
         if(dst->buf)
             H5MM_xfree(dst->buf);
         if(dst->type)
-            H5T_close(dst->type);
+            (void)H5T_close_real(dst->type);
         if(!_dst)
             dst = H5FL_FREE(H5O_fill_t, dst);
     } /* end if */
@@ -599,18 +621,18 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_copy() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_new_size
+ * Function:    H5O_fill_new_size
  *
- * Purpose:	Returns the size of the raw message in bytes not counting the
+ * Purpose:    Returns the size of the raw message in bytes not counting the
  *          message type or size fields, but only the data fields.  This
  *          function doesn't take into account alignment.  The new fill
  *          value message is fill value plus space allocation time and
  *          fill value writing time and whether fill value is defined.
  *
- * Return:	Success:	Message data size in bytes w/o alignment.
- *          Failure:	0
+ * Return:    Success:    Message data size in bytes w/o alignment.
+ *          Failure:    0
  *
  * Programmer:  Raymond Lu
  *              Feb 26, 2002
@@ -630,26 +652,26 @@ H5O_fill_new_size(const H5F_t H5_ATTR_UNUSED *f, const void *_fill)
 
     /* Determine size for different versions */
     if(fill->version < H5O_FILL_VERSION_3) {
-        ret_value = 1 +	 		/* Version number        */
-                    1 + 		/* Space allocation time */
-                    1 + 		/* Fill value write time */
-                    1; 			/* Fill value defined    */
+        ret_value = 1 +             /* Version number        */
+                    1 +         /* Space allocation time */
+                    1 +         /* Fill value write time */
+                    1;             /* Fill value defined    */
         if(fill->fill_defined)
-            ret_value += 4 +	/* Fill value size	 */
-                    (fill->size > 0 ? (size_t)fill->size : 0);	/* Size of fill value	 */
+            ret_value += 4 +    /* Fill value size     */
+                    (fill->size > 0 ? (size_t)fill->size : 0);    /* Size of fill value     */
     } /* end if */
     else {
-        ret_value = 1 +	 		/* Version number        */
-                    1;			/* Status flags          */
+        ret_value = 1 +             /* Version number        */
+                    1;            /* Status flags          */
         if(fill->size > 0)
-            ret_value += 4 +		/* Fill value size	 */
-                    (size_t)fill->size;		/* Size of fill value	 */
+            ret_value += 4 +        /* Fill value size     */
+                    (size_t)fill->size;        /* Size of fill value     */
     } /* end else */
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_new_size() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    H5O_fill_old_size
  *
@@ -677,15 +699,15 @@ H5O_fill_old_size(const H5F_t H5_ATTR_UNUSED *f, const void *_fill)
     FUNC_LEAVE_NOAPI(4 + (size_t)fill->size)
 } /* end H5O_fill_old_size() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_reset_dyn
+ * Function:    H5O_fill_reset_dyn
  *
- * Purpose:	Resets dynamic fill value fields
+ * Purpose:    Resets dynamic fill value fields
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
+ * Programmer:    Quincey Koziol
  *              Monday, January 22, 2007
  *
  *-------------------------------------------------------------------------
@@ -709,7 +731,7 @@ H5O_fill_reset_dyn(H5O_fill_t *fill)
             if(NULL == (fill_type = H5T_copy(fill->type, H5T_COPY_TRANSIENT)))
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to copy fill value datatype")
             if((fill_type_id = H5I_register(H5I_DATATYPE, fill_type, FALSE)) < 0) {
-                H5T_close(fill_type);
+                (void)H5T_close_real(fill_type);
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to register fill value datatype")
             } /* end if */
 
@@ -718,7 +740,7 @@ H5O_fill_reset_dyn(H5O_fill_t *fill)
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTCREATE, FAIL, "can't create scalar dataspace")
 
             /* Reclaim any variable length components of the fill value */
-            if(H5D_vlen_reclaim(fill_type_id, fill_space, H5AC_noio_dxpl_id, fill->buf) < 0) {
+            if(H5D_vlen_reclaim(fill_type_id, fill_space, fill->buf) < 0) {
                 H5S_close(fill_space);
                 HGOTO_ERROR(H5E_OHDR, H5E_BADITER, FAIL, "unable to reclaim variable-length fill value data")
             } /* end if */
@@ -732,8 +754,8 @@ H5O_fill_reset_dyn(H5O_fill_t *fill)
     } /* end if */
     fill->size = 0;
     if(fill->type) {
-	    H5T_close(fill->type);
-        fill->type = NULL;
+    (void)H5T_close_real(fill->type);
+    fill->type = NULL;
     } /* end if */
 
 done:
@@ -743,25 +765,25 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_reset_dyn() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_reset
+ * Function:    H5O__fill_reset
  *
- * Purpose:	Resets a message to an initial state.
+ * Purpose:    Resets a message to an initial state.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Thursday, October  1, 1998
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_fill_reset(void *_fill)
+H5O__fill_reset(void *_fill)
 {
-    H5O_fill_t	*fill = (H5O_fill_t *)_fill;
+    H5O_fill_t    *fill = (H5O_fill_t *)_fill;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     HDassert(fill);
 
@@ -774,36 +796,36 @@ H5O_fill_reset(void *_fill)
     fill->fill_defined = FALSE;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_fill_reset() */
+} /* end H5O__fill_reset() */
+
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_free
+ * Function:    H5O__fill_free
  *
- * Purpose:	Frees the message
+ * Purpose:    Frees the message
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
+ * Programmer:    Quincey Koziol
  *              Thursday, December 5, 2002
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_fill_free(void *fill)
+H5O__fill_free(void *fill)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     HDassert(fill);
 
     fill = H5FL_FREE(H5O_fill_t, fill);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_fill_free() */
+} /* end H5O__fill_free() */
+
 
-
 /*-------------------------------------------------------------------------
- * Function:    H5O_fill_pre_copy_file
+ * Function:    H5O__fill_pre_copy_file
  *
  * Purpose:     Perform any necessary actions before copying message between
  *              files.
@@ -816,13 +838,13 @@ H5O_fill_free(void *fill)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_fill_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void *mesg_src,
+H5O__fill_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void *mesg_src,
     hbool_t H5_ATTR_UNUSED *deleted, const H5O_copy_t *cpy_info, void H5_ATTR_UNUSED *udata)
 {
-    const H5O_fill_t	*fill_src = (const H5O_fill_t *)mesg_src;   /* Source fill value */
+    const H5O_fill_t    *fill_src = (const H5O_fill_t *)mesg_src;   /* Source fill value */
     herr_t ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* check args */
     HDassert(cpy_info);
@@ -835,29 +857,29 @@ H5O_fill_pre_copy_file(H5F_t H5_ATTR_UNUSED *file_src, const void *mesg_src,
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_fill_pre_copy_file() */
+} /* end H5O__fill_pre_copy_file() */
+
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_debug
+ * Function:    H5O__fill_debug
  *
- * Purpose:	Prints debugging info for the message.
+ * Purpose:    Prints debugging info for the message.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Thursday, October  1, 1998
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_fill_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const void *_fill, FILE *stream,
-	       int indent, int fwidth)
+H5O__fill_debug(H5F_t H5_ATTR_UNUSED *f, const void *_fill, FILE *stream,
+    int indent, int fwidth)
 {
     const H5O_fill_t *fill = (const H5O_fill_t *)_fill;
     H5D_fill_value_t fill_status;       /* Whether the fill value is defined */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     HDassert(f);
     HDassert(fill);
@@ -868,40 +890,40 @@ H5O_fill_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const void
     HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Space Allocation Time:");
     switch(fill->alloc_time) {
         case H5D_ALLOC_TIME_EARLY:
-            fprintf(stream,"Early\n");
+            HDfprintf(stream,"Early\n");
             break;
 
         case H5D_ALLOC_TIME_LATE:
-            fprintf(stream,"Late\n");
+            HDfprintf(stream,"Late\n");
             break;
 
         case H5D_ALLOC_TIME_INCR:
-            fprintf(stream,"Incremental\n");
+            HDfprintf(stream,"Incremental\n");
             break;
 
         case H5D_ALLOC_TIME_DEFAULT:
         case H5D_ALLOC_TIME_ERROR:
         default:
-            fprintf(stream,"Unknown!\n");
+            HDfprintf(stream,"Unknown!\n");
             break;
     } /* end switch */
     HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Fill Time:");
     switch(fill->fill_time) {
         case H5D_FILL_TIME_ALLOC:
-            fprintf(stream,"On Allocation\n");
+            HDfprintf(stream,"On Allocation\n");
             break;
 
         case H5D_FILL_TIME_NEVER:
-            fprintf(stream,"Never\n");
+            HDfprintf(stream,"Never\n");
             break;
 
         case H5D_FILL_TIME_IFSET:
-            fprintf(stream,"If Set\n");
+            HDfprintf(stream,"If Set\n");
             break;
 
         case H5D_FILL_TIME_ERROR:
         default:
-            fprintf(stream,"Unknown!\n");
+            HDfprintf(stream,"Unknown!\n");
             break;
 
     } /* end switch */
@@ -909,25 +931,25 @@ H5O_fill_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const void
     H5P_is_fill_value_defined((const H5O_fill_t *)fill, &fill_status);
     switch(fill_status) {
         case H5D_FILL_VALUE_UNDEFINED:
-            fprintf(stream,"Undefined\n");
+            HDfprintf(stream,"Undefined\n");
             break;
 
         case H5D_FILL_VALUE_DEFAULT:
-            fprintf(stream,"Default\n");
+            HDfprintf(stream,"Default\n");
             break;
 
         case H5D_FILL_VALUE_USER_DEFINED:
-            fprintf(stream,"User Defined\n");
+            HDfprintf(stream,"User Defined\n");
             break;
 
         case H5D_FILL_VALUE_ERROR:
         default:
-            fprintf(stream,"Unknown!\n");
+            HDfprintf(stream,"Unknown!\n");
             break;
 
     } /* end switch */
     HDfprintf(stream, "%*s%-*s %Zd\n", indent, "", fwidth,
-	      "Size:", fill->size);
+        "Size:", fill->size);
     HDfprintf(stream, "%*s%-*s ", indent, "", fwidth, "Data type:");
     if(fill->type) {
         H5T_debug(fill->type, stream);
@@ -937,31 +959,31 @@ H5O_fill_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const void
         HDfprintf(stream, "<dataset type>\n");
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_fill_debug() */
+} /* end H5O__fill_debug() */
+
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_fill_convert
+ * Function:    H5O_fill_convert
  *
- * Purpose:	Convert a fill value from whatever data type it currently has
+ * Purpose:    Convert a fill value from whatever data type it currently has
  *          to the specified dataset type.  The `type' field of the fill
  *          value struct will be set to NULL to indicate that it has the
  *          same type as the dataset.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Thursday, October  1, 1998
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed, hid_t dxpl_id)
+H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed)
 {
-    H5T_path_t		*tpath;			    /* Type conversion info	*/
-    void		*buf = NULL, *bkg = NULL;   /* Conversion buffers	*/
-    hid_t		src_id = -1, dst_id = -1;   /* Datatype identifiers	*/
-    herr_t      	ret_value = SUCCEED;        /* Return value */
+    H5T_path_t        *tpath;                /* Type conversion info    */
+    void        *buf = NULL, *bkg = NULL;   /* Conversion buffers    */
+    hid_t        src_id = -1, dst_id = -1;   /* Datatype identifiers    */
+    herr_t          ret_value = SUCCEED;        /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
@@ -973,7 +995,7 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed, hid_
     if(!fill->buf || !fill->type || 0 == H5T_cmp(fill->type, dset_type, FALSE)) {
         /* Don't need datatype for fill value */
         if(fill->type)
-            H5T_close(fill->type);
+            (void)H5T_close_real(fill->type);
         fill->type = NULL;
 
         /* Note that the fill value info has changed */
@@ -985,8 +1007,8 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed, hid_
     /*
      * Can we convert between source and destination data types?
      */
-    if(NULL == (tpath = H5T_path_find(fill->type, dset_type, NULL, NULL, dxpl_id, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between src and dst datatypes")
+    if(NULL == (tpath = H5T_path_find(fill->type, dset_type)))
+    HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to convert between src and dst datatypes")
 
     /* Don't bother doing anything if there will be no actual conversion */
     if(!H5T_path_noop(tpath)) {
@@ -1003,7 +1025,7 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed, hid_
         else {
             if(NULL == (buf = H5MM_malloc(H5T_get_size(dset_type))))
                 HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for type conversion")
-            HDmemcpy(buf, fill->buf, H5T_get_size(fill->type));
+            H5MM_memcpy(buf, fill->buf, H5T_get_size(fill->type));
         } /* end else */
 
         /* Use CALLOC here to clear the buffer in case later the library thinks there's
@@ -1012,16 +1034,16 @@ H5O_fill_convert(H5O_fill_t *fill, H5T_t *dset_type, hbool_t *fill_changed, hid_
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for type conversion")
 
         /* Do the conversion */
-        if(H5T_convert(tpath, src_id, dst_id, (size_t)1, (size_t)0, (size_t)0, buf, bkg, dxpl_id) < 0)
+        if(H5T_convert(tpath, src_id, dst_id, (size_t)1, (size_t)0, (size_t)0, buf, bkg) < 0)
             HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "datatype conversion failed")
 
         /* Update the fill message */
         if(buf != fill->buf) {
-            H5T_vlen_reclaim_elmt(fill->buf, fill->type, dxpl_id);
+            H5T_vlen_reclaim_elmt(fill->buf, fill->type);
             H5MM_xfree(fill->buf);
             fill->buf = buf;
         } /* end if */
-        H5T_close(fill->type);
+        (void)H5T_close_real(fill->type);
         fill->type = NULL;
         H5_CHECKED_ASSIGN(fill->size, ssize_t, H5T_get_size(dset_type), size_t);
 
@@ -1042,7 +1064,7 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_fill_convert() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    H5O_fill_set_version
  *
