@@ -13,11 +13,11 @@
 
 /*-------------------------------------------------------------------------
  *
- * Created:    H5system.c
- *      Aug 21 2006
- *      Quincey Koziol <koziol@hdfgroup.org>
+ * Created:     H5system.c
+ *              Aug 21 2006
+ *              Quincey Koziol
  *
- * Purpose:    System call wrapper implementations.
+ * Purpose:     System call wrapper implementations.
  *
  *-------------------------------------------------------------------------
  */
@@ -30,10 +30,10 @@
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"        /* Generic Functions            */
-#include "H5Eprivate.h"        /* Error handling              */
-#include "H5Fprivate.h"        /* File access                */
-#include "H5MMprivate.h"    /* Memory management            */
+#include "H5private.h"      /* Generic Functions        */
+#include "H5Eprivate.h"     /* Error handling           */
+#include "H5Fprivate.h"     /* File access              */
+#include "H5MMprivate.h"    /* Memory management        */
 
 
 /****************/
@@ -86,7 +86,9 @@ static hbool_t H5_ntzset = FALSE;
  *    prints an `hsize_t' value as a hex number right justified and
  *    zero filled in an 18-character field.
  *
- *    The conversion `a' refers to an `haddr_t' type.
+ *    The conversion 'a' refers to an haddr_t type.
+ *
+ *    The conversion 't' refers to an htri_t type.
  *
  * Return:  Success:  Number of characters printed
  *
@@ -95,12 +97,15 @@ static hbool_t H5_ntzset = FALSE;
  * Programmer:  Robb Matzke
  *              Thursday, April  9, 1998
  *
- * Modifications:
- *    Robb Matzke, 1999-07-27
- *    The `%a' format refers to an argument of `haddr_t' type
- *    instead of `haddr_t*' and the return value is correct.
  *-------------------------------------------------------------------------
  */
+/* Disable warning for "format not a string literal" here -QAK */
+/*
+ *      This pragma only needs to surround the fprintf() calls with
+ *      format_templ in the code below, but early (4.4.7, at least) gcc only
+ *      allows diagnostic pragmas to be toggled outside of functions.
+ */
+H5_GCC_DIAG_OFF(format-nonliteral)
 int
 HDfprintf(FILE *stream, const char *fmt, ...)
 {
@@ -121,7 +126,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
     HDassert(stream);
     HDassert(fmt);
 
-    va_start (ap, fmt);
+    HDva_start (ap, fmt);
     while (*fmt) {
         fwidth = prec = 0;
         zerofill = 0;
@@ -170,7 +175,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                 s = rest;
             } /* end if */
             else if ('*'==*s) {
-                fwidth = va_arg(ap, int);
+                fwidth = HDva_arg(ap, int);
                 if(fwidth < 0) {
                     leftjust = 1;
                     fwidth = -fwidth;
@@ -185,7 +190,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                     prec = (int)HDstrtol(s, &rest, 10);
                     s = rest;
                 } else if('*'==*s) {
-                    prec = va_arg(ap, int);
+                    prec = HDva_arg(ap, int);
                     s++;
                 }
                 if(prec < 1)
@@ -272,16 +277,16 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                 case 'd':
                 case 'i':
                     if(!HDstrcmp(modifier, "h")) {
-                        short x = (short)va_arg(ap, int);
+                        short x = (short)HDva_arg(ap, int);
                         n = fprintf(stream, format_templ, x);
                     } else if(!*modifier) {
-                        int x = va_arg(ap, int);
+                        int x = HDva_arg(ap, int);
                         n = fprintf(stream, format_templ, x);
                     } else if(!HDstrcmp(modifier, "l")) {
-                        long x = va_arg(ap, long);
+                        long x = HDva_arg(ap, long);
                         n = fprintf(stream, format_templ, x);
                     } else {
-                        int64_t x = va_arg(ap, int64_t);
+                        int64_t x = HDva_arg(ap, int64_t);
                         n = fprintf(stream, format_templ, x);
                     }
                     break;
@@ -291,16 +296,16 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                 case 'x':
                 case 'X':
                     if(!HDstrcmp(modifier, "h")) {
-                        unsigned short x = (unsigned short)va_arg(ap, unsigned int);
+                        unsigned short x = (unsigned short)HDva_arg(ap, unsigned int);
                         n = fprintf(stream, format_templ, x);
                     } else if(!*modifier) {
-                        unsigned int x = va_arg(ap, unsigned int); /*lint !e732 Loss of sign not really occuring */
+                        unsigned int x = HDva_arg(ap, unsigned int);
                         n = fprintf(stream, format_templ, x);
                     } else if(!HDstrcmp(modifier, "l")) {
-                        unsigned long x = va_arg(ap, unsigned long); /*lint !e732 Loss of sign not really occuring */
+                        unsigned long x = HDva_arg(ap, unsigned long);
                         n = fprintf(stream, format_templ, x);
                     } else {
-                        uint64_t x = va_arg(ap, uint64_t); /*lint !e732 Loss of sign not really occuring */
+                        uint64_t x = HDva_arg(ap, uint64_t);
                         n = fprintf(stream, format_templ, x);
                     }
                     break;
@@ -311,10 +316,10 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                 case 'g':
                 case 'G':
                     if(!HDstrcmp(modifier, "h")) {
-                        float x = (float)va_arg(ap, double);
+                        float x = (float)HDva_arg(ap, double);
                         n = fprintf(stream, format_templ, (double)x);
                     } else if(!*modifier || !HDstrcmp(modifier, "l")) {
-                        double x = va_arg(ap, double);
+                        double x = HDva_arg(ap, double);
                         n = fprintf(stream, format_templ, x);
                     } else {
                     /*
@@ -322,10 +327,10 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                     * `double' are the same thing.
                     */
 #if H5_SIZEOF_LONG_DOUBLE != H5_SIZEOF_DOUBLE
-                        long double x = va_arg(ap, long double);
+                        long double x = HDva_arg(ap, long double);
                         n = fprintf(stream, format_templ, x);
 #else
-                        double x = va_arg(ap, double);
+                        double x = HDva_arg(ap, double);
                         n = fprintf(stream, format_templ, x);
 #endif
                     }
@@ -333,7 +338,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
 
                 case 'a':
                     {
-                        haddr_t x = va_arg(ap, haddr_t); /*lint !e732 Loss of sign not really occuring */
+                        haddr_t x = HDva_arg(ap, haddr_t);
 
                         if(H5F_addr_defined(x)) {
                             len = 0;
@@ -372,14 +377,14 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                             if(fwidth)
                                 len += HDsnprintf(format_templ + len, (sizeof(format_templ) - (size_t)(len + 1)),  "%d", fwidth);
                             HDstrncat(format_templ, "s", (sizeof(format_templ) - (size_t)(len + 1)));
-                            fprintf(stream, format_templ, "UNDEF");
+                            n = fprintf(stream, format_templ, "UNDEF");
                         }
                     }
                     break;
 
                 case 'c':
                     {
-                        char x = (char)va_arg(ap, int);
+                        char x = (char)HDva_arg(ap, int);
                         n = fprintf(stream, format_templ, x);
                     }
                     break;
@@ -387,7 +392,7 @@ HDfprintf(FILE *stream, const char *fmt, ...)
                 case 's':
                 case 'p':
                     {
-                        char *x = va_arg(ap, char*); /*lint !e64 Type mismatch not really occuring */
+                        char *x = HDva_arg(ap, char*);
                         n = fprintf(stream, format_templ, x);
                     }
                     break;
@@ -399,14 +404,28 @@ HDfprintf(FILE *stream, const char *fmt, ...)
 
                 case 't':
                     {
-                        htri_t tri_var = va_arg(ap, htri_t);
+                        htri_t tri_var = HDva_arg(ap, htri_t);
 
                         if(tri_var > 0)
-                            fprintf(stream, "TRUE");
+                            n = fprintf(stream, "TRUE");
                         else if(!tri_var)
-                            fprintf(stream, "FALSE");
+                            n = fprintf(stream, "FALSE");
                         else
-                            fprintf(stream, "FAIL(%d)", (int)tri_var);
+                            n = fprintf(stream, "FAIL(%d)", (int)tri_var);
+                    }
+                    break;
+
+                case 'T':       /* Elapsed time, in seconds */
+                    {
+                        double seconds = HDva_arg(ap, double);
+                        char *time_string = H5_timer_get_time_string(seconds);
+
+                        if(time_string) {
+                            n = fprintf(stream, format_templ, time_string);
+                            HDfree(time_string);
+                        } /* end if */
+                        else
+                            n = fprintf(stream, format_templ, "(error)");
                     }
                     break;
 
@@ -423,9 +442,10 @@ HDfprintf(FILE *stream, const char *fmt, ...)
             nout++;
         }
     }
-    va_end(ap);
+    HDva_end(ap);
     return nout;
 } /* end HDfprintf() */
+H5_GCC_DIAG_ON(format-nonliteral)
 
 
 /*-------------------------------------------------------------------------
@@ -468,8 +488,6 @@ HDfprintf(FILE *stream, const char *fmt, ...)
  * Programmer:  Robb Matzke
  *              Thursday, April  9, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 #ifndef HDstrtoll
@@ -492,7 +510,8 @@ HDstrtoll(const char *s, const char **rest, int base)
     /* Optional minus or plus sign */
     if ('+'==*s) {
         s++;
-    } else if ('-'==*s) {
+    }
+    else if ('-'==*s) {
         sign = -1;
         s++;
     }
@@ -501,10 +520,12 @@ HDstrtoll(const char *s, const char **rest, int base)
     if (0==base && '0'==*s && ('x'==s[1] || 'X'==s[1])) {
         base = 16;
         s += 2;
-    } else if (0==base && '0'==*s) {
+    }
+    else if (0==base && '0'==*s) {
         base = 8;
         s++;
-    } else if (0==base) {
+    }
+    else if (0==base) {
         base = 10;
     }
 
@@ -525,7 +546,8 @@ HDstrtoll(const char *s, const char **rest, int base)
 
             if (acc*base+digit < acc) {
                 overflow = TRUE;
-            } else {
+            }
+            else {
                 acc = acc*base + digit;
             }
         }
@@ -536,7 +558,8 @@ HDstrtoll(const char *s, const char **rest, int base)
     if (overflow) {
         if (sign>0) {
             acc = ((uint64_t)1<<(8*sizeof(int64_t)-1))-1;
-        } else {
+        }
+        else {
             acc = (int64_t)((uint64_t)1<<(8*sizeof(int64_t)-1));
         }
         errno = ERANGE;
@@ -621,7 +644,7 @@ Pflock(int fd, int operation) {
     flk.l_pid = 0;              /* not used with set */
 
     /* Lock or unlock */
-    if(HDfcntl(fd, F_SETLK, flk) < 0)
+    if(HDfcntl(fd, F_SETLK, &flk) < 0)
         return -1;
 
     return 0;
@@ -636,14 +659,14 @@ Pflock(int fd, int operation) {
  * Purpose:     Wrapper function for systems where no file locking is
  *              available.
  *
- * Return:      Failure:    -1 (always fails)
+ * Return:      0 (success)
  *
  *-------------------------------------------------------------------------
  */
 int H5_ATTR_CONST
 Nflock(int H5_ATTR_UNUSED fd, int H5_ATTR_UNUSED operation) {
-    /* just fail */
-    return -1;
+    /* just succeed */
+    return 0;
 } /* end Nflock() */
 
 
@@ -822,11 +845,88 @@ Wsetenv(const char *name, const char *value, int overwrite)
 #pragma comment(lib, "advapi32.lib")
 #endif
 
+
+/*-------------------------------------------------------------------------
+ * Function:    H5_get_win32_times
+ *
+ * Purpose:     Gets the elapsed, system and user times on Windows platforms.
+ *              All time values are in seconds.
+ *
+ * Return:      Success:  0
+ *              Failure:  -1
+ *
+ * Programmer:  Dana Robinson
+ *              May 2011
+ *
+ *-------------------------------------------------------------------------
+ */
+#ifdef H5_HAVE_WIN32_API
+int
+H5_get_win32_times(H5_timevals_t *tvs /*in,out*/)
+{
+    static HANDLE process_handle;
+    ULARGE_INTEGER kernel_start;
+    ULARGE_INTEGER user_start;
+    FILETIME KernelTime;
+    FILETIME UserTime;
+    FILETIME CreationTime;
+    FILETIME ExitTime;
+    LARGE_INTEGER counts_start;
+    static LARGE_INTEGER counts_freq;
+    static hbool_t is_initialized = FALSE;
+    BOOL err;
+
+    HDassert(tvs);
+
+    if(!is_initialized) {
+        /* NOTE: This is just a pseudo handle and does not need to be closed. */
+        process_handle = GetCurrentProcess();
+        err = QueryPerformanceFrequency(&counts_freq);
+        if(0 == err)
+            return -1;
+        is_initialized = TRUE;
+    } /* end if */
+
+    /*************************
+     * System and user times *
+     *************************/
+
+    err = GetProcessTimes(process_handle, &CreationTime, &ExitTime, &KernelTime,
+            &UserTime);
+    if(0 == err)
+        return -1;
+
+    /* The 1.0E7 factor seems strange but it's due to the clock
+     * ticking in 100 ns increments.
+     */
+    kernel_start.HighPart = KernelTime.dwHighDateTime;
+    kernel_start.LowPart = KernelTime.dwLowDateTime;
+    tvs->system = (double)(kernel_start.QuadPart / 1.0E7F);
+
+    user_start.HighPart = UserTime.dwHighDateTime;
+    user_start.LowPart = UserTime.dwLowDateTime;
+    tvs->user = (double)(user_start.QuadPart / 1.0E7F);
+
+    /****************
+     * Elapsed time *
+     ****************/
+
+    err = QueryPerformanceCounter(&counts_start);
+    if(0 == err)
+        return -1;
+
+    tvs->elapsed = (double)(counts_start.QuadPart) / (double)counts_freq.QuadPart;
+
+    return 0;
+} /* end H5_get_win32_times() */
+#endif
+
 #define WloginBuffer_count 256
 static char Wlogin_buffer[WloginBuffer_count];
 
+
 char*
-Wgetlogin()
+Wgetlogin(void)
 {
 
 #ifdef H5_HAVE_WINSOCK2_H
@@ -843,9 +943,9 @@ int c99_snprintf(char* str, size_t size, const char* format, ...)
     int count;
     va_list ap;
 
-    va_start(ap, format);
+    HDva_start(ap, format);
     count = c99_vsnprintf(str, size, format, ap);
-    va_end(ap);
+    HDva_end(ap);
 
     return count;
 }
@@ -980,6 +1080,132 @@ Wroundf(float arg)
     return (float)(arg < 0.0F ? HDceil(arg - 0.5F) : HDfloor(arg + 0.5F));
 }
 
+/*-------------------------------------------------------------------------
+* Function:     H5_get_utf16_str
+*
+* Purpose:      Gets a UTF-16 string from an UTF-8 (or ASCII) string.
+*
+* Return:       Success:    A pointer to a UTF-16 string
+*                           This must be freed by the caller using H5MM_xfree()
+*               Failure:    NULL
+*
+* Programmer:  Dana Robinson
+*              Spring 2019
+*
+*-------------------------------------------------------------------------
+*/
+const wchar_t *
+H5_get_utf16_str(const char *s)
+{
+    int     nwchars = -1;       /* Length of the UTF-16 buffer */
+    wchar_t *ret_s  = NULL;     /* UTF-16 version of the string */
+
+    /* Get the number of UTF-16 characters needed */
+    if(0 == (nwchars = MultiByteToWideChar(CP_UTF8, 0, s, -1, NULL, 0)))
+        goto error;
+
+    /* Allocate a buffer for the UTF-16 string */
+    if(NULL == (ret_s = (wchar_t *)H5MM_calloc(sizeof(wchar_t) * (size_t)nwchars)))
+        goto error;
+
+    /* Convert the input UTF-8 string to UTF-16 */
+    if(0 == MultiByteToWideChar(CP_UTF8, 0, s, -1, ret_s, nwchars))
+        goto error;
+
+    return ret_s;
+
+error:
+    if(ret_s)
+        H5MM_xfree((void *)ret_s);
+    return NULL;
+}   /* end H5_get_utf16_str() */
+
+/*-------------------------------------------------------------------------
+ * Function:     Wopen_utf8
+ *
+ * Purpose:      UTF-8 equivalent of open(2) for use on Windows.
+ *               Converts a UTF-8 input path to UTF-16 and then opens the
+ *               file via _wopen() under the hood
+ *
+ * Return:       Success:    A POSIX file descriptor
+ *               Failure:    -1
+ *
+ * Programmer:  Dana Robinson
+ *              Spring 2019
+ *
+ *-------------------------------------------------------------------------
+ */
+int
+Wopen_utf8(const char *path, int oflag, ...)
+{
+    int fd          = -1;       /* POSIX file descriptor to be returned */
+    wchar_t *wpath  = NULL;     /* UTF-16 version of the path */
+    int pmode       = 0;        /* mode (optionally set via variable args) */
+
+    /* Convert the input UTF-8 path to UTF-16 */
+    if(NULL == (wpath = H5_get_utf16_str(path)))
+        goto done;
+
+    /* _O_BINARY must be set in Windows to avoid CR-LF <-> LF EOL
+    * transformations when performing I/O. Note that this will
+    * produce Unix-style text files, though.
+    */
+    oflag |= _O_BINARY;
+
+    /* Get the mode, if O_CREAT was specified */
+    if(oflag & O_CREAT) {
+        va_list vl;
+
+        HDva_start(vl, oflag);
+        pmode = HDva_arg(vl, int);
+        HDva_end(vl);
+    }
+
+    /* Open the file */
+    fd = _wopen(wpath, oflag, pmode);
+
+done:
+    if(wpath)
+        H5MM_xfree((void *)wpath);
+
+    return fd;
+}   /* end Wopen_utf8() */
+
+/*-------------------------------------------------------------------------
+ * Function:     Wremove_utf8
+ *
+ * Purpose:      UTF-8 equivalent of remove(3) for use on Windows.
+ *               Converts a UTF-8 input path to UTF-16 and then opens the
+ *               file via _wremove() under the hood
+ *
+ * Return:       Success:    0
+ *               Failure:    -1
+ *
+ * Programmer:  Dana Robinson
+ *              Spring 2019
+ *
+ *-------------------------------------------------------------------------
+ */
+int
+Wremove_utf8(const char *path)
+{
+    wchar_t *wpath = NULL;     /* UTF-16 version of the path */
+    int ret;
+
+    /* Convert the input UTF-8 path to UTF-16 */
+    if(NULL == (wpath = H5_get_utf16_str(path)))
+        goto done;
+
+    /* Open the file */
+    ret = _wremove(wpath);
+
+done:
+    if(wpath)
+        H5MM_xfree((void *)wpath);
+
+    return ret;
+}   /* end Wremove_utf8() */
+
 #endif /* H5_HAVE_WIN32_API */
 
 
@@ -1125,13 +1351,13 @@ H5_combine_path(const char* path1, const char* path2, char **full_name /*out*/)
 
     FUNC_ENTER_NOAPI_NOINIT
 
-    HDassert(path1);
     HDassert(path2);
 
-    path1_len = HDstrlen(path1);
+    if(path1)
+        path1_len = HDstrlen(path1);
     path2_len = HDstrlen(path2);
 
-    if(*path1 == '\0' || H5_CHECK_ABSOLUTE(path2)) {
+    if(path1 == NULL || *path1 == '\0' || H5_CHECK_ABSOLUTE(path2)) {
 
         /* If path1 is empty or path2 is absolute, simply use path2 */
         if(NULL == (*full_name = (char *)H5MM_strdup(path2)))
@@ -1165,11 +1391,11 @@ H5_combine_path(const char* path1, const char* path2, char **full_name /*out*/)
          * Allocate a buffer to hold path1 + path2 + possibly the delimiter
          *      + terminating null byte
          */
-        if(NULL == (*full_name = (char *)H5MM_malloc(path1_len + path2_len + 2)))
+        if(NULL == (*full_name = (char *)H5MM_malloc(path1_len + path2_len + 2 + 2))) /* Extra "+2" to quiet GCC warning - 2019/07/05, QAK */
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "unable to allocate filename buffer")
 
         /* Compose the full file name */
-        HDsnprintf(*full_name, (path1_len + path2_len + 2), "%s%s%s", path1,
+        HDsnprintf(*full_name, (path1_len + path2_len + 2 + 2), "%s%s%s", path1, /* Extra "+2" to quiet GCC warning - 2019/07/05, QAK */
                    (H5_CHECK_DELIMITER(path1[path1_len - 1]) ? "" : H5_DIR_SEPS), path2);
     } /* end else */
 
@@ -1205,38 +1431,6 @@ H5_nanosleep(uint64_t nanosec)
     FUNC_LEAVE_NOAPI_VOID
 } /* end H5_nanosleep() */
 
-
-/*--------------------------------------------------------------------------
- * Function:    H5_get_time
- *
- * Purpose:     Get the current time, as the time of seconds after the UNIX epoch
- *
- * Return:      SUCCEED/FAIL
- *
- * Programmer:  Quincey Koziol
- *              October 05, 2016
- *--------------------------------------------------------------------------
- */
-double
-H5_get_time(void)
-{
-#ifdef H5_HAVE_GETTIMEOFDAY
-    struct timeval curr_time;
-#endif /* H5_HAVE_GETTIMEOFDAY */
-    double ret_value = (double)0.0f;
-
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
-
-#ifdef H5_HAVE_GETTIMEOFDAY
-    HDgettimeofday(&curr_time, NULL);
-
-    ret_value = (double)curr_time.tv_sec + ((double)curr_time.tv_usec / (double)1000000.0f);
-#endif /* H5_HAVE_GETTIMEOFDAY */
-
-    FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5_get_time() */
-
-
 #ifdef H5_HAVE_WIN32_API
 
 #define H5_WIN32_ENV_VAR_BUFFER_SIZE    32767
